@@ -7,12 +7,20 @@ from sqlalchemy.orm import relationship
 
 from fief.models.base import WorkspaceBase
 from fief.models.client import Client
-from fief.models.generics import GUID, CreatedUpdatedAt, TIMESTAMPAware, UUIDModel
+from fief.models.generics import (
+    GUID,
+    CreatedUpdatedAt,
+    ExpiresAt,
+    TIMESTAMPAware,
+    UUIDModel,
+)
 from fief.models.user import User
+from fief.settings import settings
 
 
-class RefreshToken(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
+class RefreshToken(UUIDModel, CreatedUpdatedAt, ExpiresAt, WorkspaceBase):
     __tablename__ = "refresh_tokens"
+    __lifetime_seconds__ = settings.refresh_token_lifetime_seconds
 
     token: str = Column(
         String(length=255),
@@ -20,9 +28,6 @@ class RefreshToken(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
         index=True,
         unique=True,
     )
-    expires_at: datetime = Column(
-        TIMESTAMPAware(timezone=True), nullable=False, index=True
-    )
     scope: List[str] = Column(JSON, nullable=False, default=list)
     authenticated_at: datetime = Column(TIMESTAMPAware(timezone=True), nullable=False)
 
